import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { ActivatedRoute, Router, RouterModule } from '@angular/router';
import { MatInputModule, MatAutocompleteModule, MatChipsModule, MatIconModule, MatSelectModule, MatSlideToggleModule, MatProgressBarModule, MatButtonModule, MatTabsModule, MatRippleModule, MatCardModule, MatToolbarModule } from '@angular/material';
import { Injectable, Pipe, Component, Input, Output, EventEmitter, ChangeDetectorRef, ViewChild, defineInjectable, inject, NgModule } from '@angular/core';
import { BehaviorSubject, throwError, Subject } from 'rxjs';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoadingService {
    constructor() {
        this.delay = 250;
        this.loaders = 0;
        this.time = 0;
        this.loadingSubject = new BehaviorSubject(false);
    }
    /**
     * @return {?}
     */
    getLoading() {
        return this.loadingSubject.asObservable();
    }
    /**
     * @return {?}
     */
    setLoading() {
        this.loaders++;
        this.time = Date.now();
        this.loadingSubject.next(true);
        if (this.timeout) {
            clearTimeout(this.timeout);
        }
    }
    /**
     * @return {?}
     */
    unsetLoading() {
        this.loaders--;
        if (this.loaders < 0)
            this.loaders = 0;
        if (this.loaders == 0) {
            this.timeout = setTimeout((/**
             * @return {?}
             */
            () => {
                this.loadingSubject.next(false);
            }), this.delay - (Date.now() - this.time));
        }
    }
}
LoadingService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
LoadingService.ctorParameters = () => [];
/** @nocollapse */ LoadingService.ngInjectableDef = defineInjectable({ factory: function LoadingService_Factory() { return new LoadingService(); }, token: LoadingService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UtilsService {
    /**
     * @param {?} router
     * @param {?} route
     * @param {?} loadingService
     */
    constructor(router, route, loadingService) {
        this.router = router;
        this.route = route;
        this.loadingService = loadingService;
        this.paramsSubject = new BehaviorSubject(null);
        route.queryParams.subscribe((/**
         * @param {?} params
         * @return {?}
         */
        params => {
            if (Object.keys(params).length > 0)
                this.setParams(params);
        }));
    }
    /**
     * @param {?} params
     * @return {?}
     */
    objectToQuerystring(params) {
        /** @type {?} */
        let searchParams = new URLSearchParams();
        Object.keys(params).forEach((/**
         * @param {?} key
         * @return {?}
         */
        (key) => searchParams.append(key, params[key])));
        return '?' + searchParams.toString();
    }
    /**
     * @param {?} on
     * @param {?} callback
     * @return {?}
     */
    setRedirect(on, callback) {
        if (this.redirectParams)
            return;
        /** @type {?} */
        const url = new URL(callback.replace('#', '%23'));
        this.redirectParams = { on, callback: url };
    }
    /**
     * @return {?}
     */
    getRedirect() {
        return this.redirectParams;
    }
    /**
     * @param {?} on
     * @param {?} params
     * @param {?=} navigate
     * @return {?}
     */
    redirect(on, params, navigate) {
        if (this.redirectParams) {
            if (this.redirectParams && this.redirectParams.on === on) {
                for (let param of this.redirectParams.callback.searchParams) {
                    params[param[0]] = params[1];
                }
                window.location.replace(`${this.redirectParams.callback.origin}${this.redirectParams.callback.pathname.replace('%23', '#')}${this.objectToQuerystring(params)}`);
                return false;
            }
            return [`/${this.redirectParams.on}`];
        }
        if (navigate) {
            return navigate;
        }
    }
    /**
     * @param {?} params
     * @return {?}
     */
    setParams(params) {
        this.paramsSubject.next(params);
    }
    /**
     * @return {?}
     */
    getParams() {
        return this.paramsSubject.asObservable();
    }
    /**
     * @param {?} options
     * @return {?}
     */
    filter(options) {
        /** @type {?} */
        const search = options.search.normalize('NFD').replace(/[\u0300-\u036f]/g, "").toLowerCase();
        /** @type {?} */
        let items = [];
        for (let item of options.items) {
            for (let key of options.keys) {
                if (Array.isArray(item[key])) {
                    /** @type {?} */
                    let result = false;
                    for (let word of item[key]) {
                        if (word.toString().normalize('NFD').replace(/[\u0300-\u036f]/g, "").toLowerCase().indexOf(search) > -1) {
                            items.push(item);
                            result = true;
                            break;
                        }
                    }
                    if (result)
                        break;
                    continue;
                }
                if (item[key].toString().normalize('NFD').replace(/[\u0300-\u036f]/g, "").toLowerCase().indexOf(search) > -1) {
                    items.push(item);
                    break;
                }
            }
        }
        return items;
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        this.loadingService.unsetLoading();
        /** @type {?} */
        let errorText;
        if (error.error instanceof ProgressEvent) {
            // A client-side or network error occurred. Handle it accordingly.
            console.error('An error occurred:', error.message);
            errorText = 'Error en la red';
        }
        else {
            console.error(`Backend returned code ${error.status}, body was: `, error.error);
            switch (error.error.code) {
                case 'duplicate_key':
                    errorText = `Parámetro ${error.error.key} duplicado`;
                    break;
                case 'invalid_parameters':
                    errorText = `Parámetro ${error.error.violations[0].context.label} inválido`;
                    break;
                default:
                    errorText = error.error.message;
                    break;
            }
        }
        // return an observable with a user-facing error message
        return throwError(errorText);
    }
}
UtilsService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
UtilsService.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: LoadingService }
];
/** @nocollapse */ UtilsService.ngInjectableDef = defineInjectable({ factory: function UtilsService_Factory() { return new UtilsService(inject(Router), inject(ActivatedRoute), inject(LoadingService)); }, token: UtilsService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @return {?}
 */
function _window() {
    // return the global native browser window object
    return window;
}
class WindowRef {
    /**
     * @return {?}
     */
    get nativeWindow() {
        return _window();
    }
}
WindowRef.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectComponent {
    constructor() {
        this.item = {};
        this.label = '';
        this.options = [];
        this.optionsLabels = [];
        this.editing = true;
        this.itemChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-select',
                template: "<mat-form-field class=\"w-100\">\n\t<mat-select [placeholder]=\"label\" [disabled]=\"!editing\" [value]=\"item\" (valueChange)=\"itemChange.emit($event)\">\n\t\t<mat-option [value]=\"option\" *ngFor=\"let option of options; let i = index;\">{{optionsLabels[i]}}</mat-option>\n\t</mat-select>\n</mat-form-field>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
SelectComponent.ctorParameters = () => [];
SelectComponent.propDecorators = {
    item: [{ type: Input }],
    label: [{ type: Input }],
    options: [{ type: Input }],
    optionsLabels: [{ type: Input }],
    editing: [{ type: Input }],
    itemChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonComponent {
    constructor() {
        this.label = [];
        this.disabled = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
ButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-button',
                template: "<a class=\"input-container w-100\" [class.disabled]=\"disabled\" [class.text-danger]=\"danger\" [routerLink]=\"\" *ngIf=\"!link\"><span class=\"text-center w-100\">{{label}}</span></a>\n<a class=\"input-container w-100\" [class.disabled]=\"disabled\" [class.text-danger]=\"danger\" [routerLink]=\"[link]\" *ngIf=\"link\"><span class=\"text-center w-100\">{{label}}</span></a>\n",
                styles: [".rounded{border-radius:.25rem!important}.shadow-center-2{box-shadow:0 3px 6px rgba(0,0,0,.16),0 3px 6px rgba(0,0,0,.23)}.shadow-center-3{box-shadow:0 6px 20px rgba(0,0,0,.19),0 6px 6px rgba(0,0,0,.23)}.input-container .input-button,.shadow-1{box-shadow:0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24)}.shadow-2{box-shadow:0 3px 6px rgba(0,0,0,.16),0 3px 6px rgba(0,0,0,.23)}.shadow-3{box-shadow:0 10px 20px rgba(0,0,0,.19),0 6px 6px rgba(0,0,0,.23)}.shadow-4{box-shadow:0 14px 28px rgba(0,0,0,.25),0 10px 10px rgba(0,0,0,.22)}.shadow-5{box-shadow:0 19px 38px rgba(0,0,0,.3),0 15px 12px rgba(0,0,0,.22)}.z-index-0{z-index:-10}.z-index-1{z-index:0}.z-index-2{z-index:10}.z-index-3{z-index:100}.z-index-4{z-index:1000}.rounded-top-0{border-top-left-radius:0!important;border-top-right-radius:0!important}.rounded-bottom-0{border-bottom-left-radius:0!important;border-bottom-right-radius:0!important}.center-childs{display:flex;align-items:center}.input-container{padding:0!important;display:flex;align-items:center;cursor:pointer;text-decoration:none;user-drag:none;-webkit-user-drag:none}.input-container.disabled{pointer-events:none;opacity:.65}.input-container:hover{text-decoration:none!important}.input-container:focus{border-color:#ced4da!important;outline:0;box-shadow:none!important}.input-container .input-button{margin-left:auto;margin-right:auto;background-color:#069;text-align:center;color:#fff;font-size:20px;cursor:pointer;transition:.2s;padding-top:0;padding-bottom:0;border-radius:.25rem;width:100%}.input-container .input-button.danger{background-color:#dc3545}.input-container .input-button:hover{background-color:#046;transition:.2s}.input-container .input-button p{margin:0;padding:5px 0}"]
            }] }
];
/** @nocollapse */
ButtonComponent.ctorParameters = () => [];
ButtonComponent.propDecorators = {
    label: [{ type: Input }],
    link: [{ type: Input }],
    disabled: [{ type: Input }],
    danger: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationComponent {
    constructor() {
        this.pageSize = 10;
        this.maxPages = 3;
        this.itemsChange = new EventEmitter();
        this.page = 1;
    }
    /**
     * @return {?}
     */
    get pages() {
        return Math.ceil(this.items.length / this.pageSize);
    }
    /**
     * @return {?}
     */
    get numbers() {
        /** @type {?} */
        let first = Math.round(this.page - this.maxPages / 2);
        first = first < 1 ? 1 : first;
        /** @type {?} */
        let last = first + this.maxPages - 1;
        last = last > this.pages ? this.pages : last;
        /** @type {?} */
        let ans = [];
        for (let i = first; i <= last; i++) {
            ans.push(i);
        }
        return ans;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (this.page > this.pages) {
            this.page = this.pages;
        }
        if (this.page < 1) {
            this.page = 1;
        }
        this.updateItems();
    }
    /**
     * @return {?}
     */
    updateItems() {
        this.itemsChange.emit(this.items.slice((this.page - 1) * this.pageSize, this.page * this.pageSize));
    }
    /**
     * @param {?} page
     * @return {?}
     */
    goPage(page) {
        this.page = page;
        this.updateItems();
    }
    /**
     * @return {?}
     */
    nextPage() {
        this.page++;
        this.updateItems();
    }
    /**
     * @return {?}
     */
    prevPage() {
        this.page--;
        this.updateItems();
    }
}
PaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-pagination',
                template: "<nav aria-label=\"Page navigation example\" *ngIf=\"items && items.length > 0\">\n\t<ul class=\"pagination\">\n\t\t<li class=\"page-item\">\n\t\t\t<a class=\"page-link\" [routerLink]=\"\" (click)=\"prevPage()\" [class.disabled]=\"page <= 1\">\n\t\t\t\t<span>Anterior</span>\n\t\t\t</a>\n\t\t</li>\n\t\t<li class=\"page-item\" *ngIf=\"numbers[0] !== 1\"><a class=\"page-link\" [routerLink]=\"\" (click)=\"goPage(1)\">{{1}}</a></li>\n\t\t<li class=\"page-item\" *ngFor=\"let i of numbers\" [class.active]=\"i === page\"><a class=\"page-link\" [routerLink]=\"\" (click)=\"goPage(i)\">{{i}}</a></li>\n\t\t<li class=\"page-item\" *ngIf=\"numbers[numbers.length - 1] !== pages\"><a class=\"page-link\" [routerLink]=\"\" (click)=\"goPage(pages)\">{{pages}}</a></li>\n\t\t<li class=\"page-item\">\n\t\t\t<a class=\"page-link\" [routerLink]=\"\" (click)=\"nextPage()\" [class.disabled]=\"page >= pages\">\n\t\t\t\t<span>Siguiente</span>\n\t\t\t</a>\n\t\t</li>\n\t</ul>\n</nav>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
PaginationComponent.ctorParameters = () => [];
PaginationComponent.propDecorators = {
    items: [{ type: Input }],
    pageSize: [{ type: Input }],
    maxPages: [{ type: Input }],
    itemsChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchComponent {
    constructor() {
        this.searchChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    emit() {
        this.searchChange.emit(this.search);
    }
}
SearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-search',
                template: "<div class=\"input-group\">\n\t<input type=\"text\" [(ngModel)]=\"search\" (ngModelChange)=\"emit()\" class=\"form-control\" placeholder=\"Buscar...\" autofocus>\n\t<span class=\"input-group-append\">\n\t\t<button class=\"btn btn-secondary\" type=\"button\"><span class=\"fas fa-search\"></span>&#0;</button>\n\t</span>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
SearchComponent.ctorParameters = () => [];
SearchComponent.propDecorators = {
    search: [{ type: Input }],
    searchChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListComponent {
    /**
     * @param {?} cdRef
     */
    constructor(cdRef) {
        this.cdRef = cdRef;
        this.rawItems = [];
        this.labels = [];
        this.keys = [];
        this.dateFormat = 'dd/MM/yyyy';
        this.linkKey = '';
        this.linkLabel = '';
        this.disabled = '';
        this.items = [];
        this._callback = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} item
     * @return {?}
     */
    callback(item) {
        this._callback.emit(this.linkKey.split('.').reduce((/**
         * @param {?} prev
         * @param {?} curr
         * @return {?}
         */
        (prev, curr) => prev && prev[curr]), item));
    }
    /**
     * @return {?}
     */
    detectChanges() {
        this.cdRef.detectChanges();
    }
}
ListComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-list',
                template: "<div class=\"main\">\n\t<table class=\"table\">\n\t\t<thead>\n\t\t\t<tr>\n\t\t\t\t<th scope=\"col\" *ngFor=\"let label of labels\"><span>{{label}}</span></th>\n\t\t\t\t<th></th>\n\t\t\t</tr>\n\t\t</thead>\n\t\t<tbody>\n\t\t\t<ng-container *ngIf=\"items && items.length > 0\">\n\t\t\t\t<tr class=\"\" *ngFor=\"let item of items\">\n\t\t\t\t\t<ng-container *ngFor=\"let key of keys; let i = index\">\n\t\t\t\t\t\t<th scope=\"row\" *ngIf=\"i === 0\">\n\t\t\t\t\t\t\t<ng-container *ngIf=\"link\">\n\t\t\t\t\t\t\t\t<a class=\"\" [routerLink]=\"[link + (item | property:linkKey)]\">\n\t\t\t\t\t\t\t\t\t<span *ngIf=\"key.toLowerCase().includes('date')\">{{item | property:key | date:dateFormat}}</span>\n\t\t\t\t\t\t\t\t\t<span *ngIf=\"!key.toLowerCase().includes('date')\">{{item | property:key}}</span>\n\t\t\t\t\t\t\t\t</a>\n\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t<ng-container *ngIf=\"!link\">\n\t\t\t\t\t\t\t\t<span *ngIf=\"key.toLowerCase().includes('date')\">{{item | property:key | date:dateFormat}}</span>\n\t\t\t\t\t\t\t\t<span *ngIf=\"!key.toLowerCase().includes('date')\">{{item | property:key}}</span>\n\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t</th>\n\t\t\t\t\t\t<td *ngIf=\"i !== 0\">\n\t\t\t\t\t\t\t<span *ngIf=\"key.toLowerCase().includes('date')\">{{item | property:key | date:dateFormat}}</span>\n\t\t\t\t\t\t\t<span *ngIf=\"!key.toLowerCase().includes('date')\">{{item | property:key}}</span>\n\t\t\t\t\t\t</td>\n\t\t\t\t\t</ng-container>\n\n\t\t\t\t\t<td>\n\t\t\t\t\t\t<ieeesb-button [label]=\"linkLabel\" [link]=\"link + (item | property:linkKey)\" (click)=\"callback(item)\" *ngIf=\"link\" [disabled]=\"item | property:disabled\"></ieeesb-button>\n\t\t\t\t\t\t<ieeesb-button [label]=\"linkLabel\" (click)=\"callback(item)\" *ngIf=\"!link\" [disabled]=\"item | property:disabled\"></ieeesb-button>\n\t\t\t\t\t</td>\n\t\t\t\t</tr>\n\t\t\t</ng-container>\n\t\t</tbody>\n\t</table>\n</div>\n<div class=\"row justify-content-center mt-3 mx-0\">\n\t<div class=\"col-auto\">\n\t\t<ieeesb-pagination [items]=\"rawItems\" (itemsChange)=\"items=$event; detectChanges();\" pageSize=\"10\"></ieeesb-pagination>\n\t</div>\n</div>\n<div *ngIf=\"!items || items.length <= 0\">\n\tNo hay resultados...\n</div>\n",
                styles: [".main{overflow-x:auto}td,th{border-top:0!important;border-bottom:0!important;text-align:center!important}span{white-space:nowrap;width:100%}"]
            }] }
];
/** @nocollapse */
ListComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
ListComponent.propDecorators = {
    rawItems: [{ type: Input, args: ['items',] }],
    labels: [{ type: Input }],
    keys: [{ type: Input }],
    dateFormat: [{ type: Input }],
    link: [{ type: Input }],
    linkKey: [{ type: Input }],
    linkLabel: [{ type: Input }],
    disabled: [{ type: Input }],
    _callback: [{ type: Output, args: ['callback',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PropertyPipe {
    /**
     * @param {?} value
     * @param {?=} args
     * @return {?}
     */
    transform(value, args) {
        /** @type {?} */
        const properties = Array.isArray(args) ? args : args.split('.');
        return properties.reduce((/**
         * @param {?} prev
         * @param {?} curr
         * @return {?}
         */
        (prev, curr) => prev && prev[curr]), value);
    }
}
PropertyPipe.decorators = [
    { type: Pipe, args: [{
                name: 'property'
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuComponent {
    constructor() {
        this.navbarOpen = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    toggleNavbar() {
        this.navbarOpen = !this.navbarOpen;
    }
    /**
     * @param {?} roles
     * @return {?}
     */
    userHasRoles(roles) {
        if (!this.user)
            return false;
        return roles.reduce((/**
         * @param {?} l
         * @param {?} a
         * @return {?}
         */
        (l, a) => this.user.roles.indexOf(a) >= 0 && l), true);
    }
}
MenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-menu',
                template: "<nav class=\"navbar navbar-expand-lg navbar-light\" [ngClass]=\"{ 'fixed-left': align === 'left', 'fixed-right': align === 'right' }\">\n\t<a class=\"navbar-brand\" href=\"#\">\n\t\t<img alt=\"Logo IEEEsb\" src=\"assets/logo_entero.svg\">\n\t</a>\n\t<button class=\"navbar-toggler mr-2\" type=\"button\" (click)=\"toggleNavbar()\">\n\t\t<span class=\"navbar-toggler-icon\"></span>\n\t</button>\n\t<div class=\"collapse navbar-collapse\" [ngClass]=\"{ 'show': navbarOpen }\">\n\t\t<ul class=\"navbar-nav mr-auto\">\n\t\t\t<div *ngFor=\"let item of items.left\">\n\t\t\t\t<div *ngIf=\"(!item.roles && !user) || (item.roles && userHasRoles(item.roles))\">\n\t\t\t\t\t<li *ngIf=\"item.type === 'router'\" class=\"nav-item\" [ngClass]=\"{ 'active': activeLink.startsWith(item.link) }\">\n\t\t\t\t\t\t<a class=\"nav-link\" [routerLink]=\"item.link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'link'\" class=\"nav-item\">\n\t\t\t\t\t\t<a class=\"nav-link\" [href]=\"item.link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'callback'\" class=\"nav-item\">\n\t\t\t\t\t\t<a class=\"nav-link\" href=\"javascript:;\" (click)=\"item.callback()\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'text'\" class=\"nav-item text\">\n\t\t\t\t\t\t<a class=\"nav-link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t</div>\n\t\t\t</div>\n\t\t</ul>\n\t\t<ul class=\"navbar-nav ml-auto\">\n\t\t\t<div *ngFor=\"let item of items.right\">\n\t\t\t\t<div *ngIf=\"(!item.roles && !user) || (item.roles && userHasRoles(item.roles))\">\n\t\t\t\t\t<li *ngIf=\"item.type === 'router'\" class=\"nav-item\" [ngClass]=\"{ 'active': activeLink.startsWith(item.link) }\">\n\t\t\t\t\t\t<a class=\"nav-link\" [routerLink]=\"item.link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'link'\" class=\"nav-item\">\n\t\t\t\t\t\t<a class=\"nav-link\" [href]=\"item.link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'callback'\" class=\"nav-item\">\n\t\t\t\t\t\t<a class=\"nav-link\" href=\"javascript:;\" (click)=\"item.callback()\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t\t<li *ngIf=\"item.type === 'text'\" class=\"nav-item text\">\n\t\t\t\t\t\t<a class=\"nav-link\"><span>{{item.text}}</span></a>\n\t\t\t\t\t</li>\n\t\t\t\t</div>\n\t\t\t</div>\n\t\t</ul>\n\t</div>\n</nav>\n",
                styles: [".navbar{color:#fff;padding:0;background-color:#4285f4;box-shadow:0 -3px 20px 0 #000}.navbar .navbar-brand{color:#fff;padding:0 15px;display:flex;align-items:center;margin:0;z-index:10;background-color:#fff!important}.navbar:not(.fixed-left):not(.fixed-right) .navbar-brand{height:50px}.navbar:not(.fixed-left):not(.fixed-right) img{height:40px}.navbar .navbar-collapse{border-top:1px solid #0000007d}.navbar .nav-item{height:50px}.navbar .nav-item.active,.navbar .nav-item:hover:not(.text){background-color:#519ffc!important}.navbar .nav-item a{display:flex;align-items:center;height:100%;padding:0 15px;color:#fff}@media (min-width:992px){.navbar .navbar-brand{box-shadow:3px 0 20px -10px #000}.navbar .navbar-collapse{border-top:none}.navbar.fixed-left{right:auto;float:left}.navbar.fixed-right{left:auto;float:right}.navbar.fixed-left,.navbar.fixed-right{height:100%;flex-flow:column nowrap;align-items:flex-start;bottom:0}.navbar.fixed-left .navbar-brand,.navbar.fixed-right .navbar-brand{padding-top:10px;padding-bottom:10px;box-shadow:0 3px 20px -10px #000}.navbar.fixed-left .navbar-brand img,.navbar.fixed-right .navbar-brand img{height:auto!important;width:160px!important}}@media (max-width:991px){.navbar.fixed-left .navbar-brand,.navbar.fixed-right .navbar-brand{height:50px;padding-top:10px;padding-bottom:10px}.navbar.fixed-left .navbar-brand img,.navbar.fixed-right .navbar-brand img{height:50px;width:auto}}.navbar.fixed-left .navbar-collapse,.navbar.fixed-right .navbar-collapse{flex-grow:0;flex-direction:column;width:100%}.navbar.fixed-left .navbar-collapse .navbar-nav,.navbar.fixed-right .navbar-collapse .navbar-nav{flex-direction:column;width:100%}.navbar.fixed-left .navbar-collapse .navbar-nav .nav-item,.navbar.fixed-right .navbar-collapse .navbar-nav .nav-item{width:100%}.navbar.fixed-left .navbar-collapse .navbar-nav .nav-item span,.navbar.fixed-right .navbar-collapse .navbar-nav .nav-item span{text-align:center;width:100%}.navbar.fixed-left .navbar-collapse .navbar-nav .nav-item .dropdown-toggle:after,.navbar.fixed-right .navbar-collapse .navbar-nav .nav-item .dropdown-toggle:after{border-top:2px solid transparent;border-left:2px solid;border-bottom:2px solid transparent;border-right:none;vertical-align:baseline}.navbar.fixed-left .navbar-collapse .navbar-nav .nav-item .dropdown-menu,.navbar.fixed-right .navbar-collapse .navbar-nav .nav-item .dropdown-menu{left:100%;top:0}"]
            }] }
];
/** @nocollapse */
MenuComponent.ctorParameters = () => [];
MenuComponent.propDecorators = {
    items: [{ type: Input }],
    align: [{ type: Input }],
    user: [{ type: Input }],
    activeLink: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SectionComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
SectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-section',
                template: "<div class=\"row justify-content-center mt-2\">\n\t<div class=\"col-8\">\n\t\t<hr>\n\t</div>\n</div>\n<div class=\"row justify-content-center pt-4 pb-2 mb-3 mx-0\">\n\t<div class=\"col px-0\">\n\t\t<ng-content></ng-content>\n\t</div>\n</div>\n",
                styles: ["hr{border-top:1px solid #006df0;margin-top:0;margin-bottom:0}"]
            }] }
];
/** @nocollapse */
SectionComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilterPipe {
    /**
     * @param {?} utilsService
     */
    constructor(utilsService) {
        this.utilsService = utilsService;
    }
    /**
     * @param {?} value
     * @param {?} search
     * @param {?} keys
     * @return {?}
     */
    transform(value, search, keys) {
        return this.utilsService.filter({
            search,
            keys,
            items: value,
        });
    }
}
FilterPipe.decorators = [
    { type: Pipe, args: [{
                name: 'filter'
            },] }
];
/** @nocollapse */
FilterPipe.ctorParameters = () => [
    { type: UtilsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TitleComponent {
    constructor() {
        this.title = '';
        this.linkLabel = '';
        this.disabled = false;
        this.searchChange = new EventEmitter();
        this.callback = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
TitleComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-title',
                template: "<div class=\"row justify-content-between mb-3\">\n\t<div class=\"col-12 col-md-auto\">\n\t\t<div class=\"row\">\n\t\t\t<div class=\"col-12 col-md-auto text-center align-self-center\">\n\t\t\t\t<span class=\"h2\">{{title}}</span>\n\t\t\t</div>\n\t\t\t<div class=\"col-12 col-md-6 mt-3 mt-md-0 align-self-center\" *ngIf=\"search !== null && search !== undefined\">\n\t\t\t\t<ieeesb-search [search]=\"search\" (searchChange)=\"searchChange.emit($event)\"></ieeesb-search>\n\t\t\t</div>\n\t\t</div>\n\t</div>\n\t<div class=\"col-12 col-md-2 col-lg-3 col-xl-3 mt-3 mt-md-0 align-self-center\" *ngIf=\"linkLabel\">\n\t\t<ieeesb-button [label]=\"linkLabel\" [link]=\"link\" (click)=\"callback.emit()\" *ngIf=\"link\" [disabled]=\"disabled\"></ieeesb-button>\n\t\t<ieeesb-button [label]=\"linkLabel\" (click)=\"callback.emit()\" *ngIf=\"!link\" [disabled]=\"disabled\"></ieeesb-button>\n\t</div>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
TitleComponent.ctorParameters = () => [];
TitleComponent.propDecorators = {
    title: [{ type: Input }],
    link: [{ type: Input }],
    linkLabel: [{ type: Input }],
    search: [{ type: Input }],
    disabled: [{ type: Input }],
    searchChange: [{ type: Output }],
    callback: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TagsComponent {
    constructor() {
        this.label = '';
        this.editing = true;
        this.itemChange = new EventEmitter();
        this.enter = new EventEmitter();
        this.search = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    get tags() {
        /** @type {?} */
        const filterValue = this.search.normalize('NFD').replace(/[\u0300-\u036f]/g, "").toLowerCase();
        return this.rawTags.filter((/**
         * @param {?} tag
         * @return {?}
         */
        tag => tag.normalize('NFD').replace(/[\u0300-\u036f]/g, "").toLowerCase().indexOf(filterValue) > -1 && this.item.indexOf(tag) < 0));
    }
    /**
     * @param {?} tag
     * @return {?}
     */
    addTag(tag) {
        if (tag === '')
            return;
        if (!this.item) {
            this.item = [];
        }
        if (this.item.indexOf(tag) > -1)
            return;
        this.item.push(tag);
        this.itemChange.emit(this.item);
        this.inputfield.nativeElement.value = '';
    }
    /**
     * @param {?} tag
     * @return {?}
     */
    add(tag) {
        // Add fruit only when MatAutocomplete is not open
        // To make sure this does not conflict with OptionSelected Event
        if (!this.matAutocomplete.isOpen) {
            this.addTag(tag);
        }
    }
    /**
     * @param {?} tag
     * @return {?}
     */
    removeTag(tag) {
        if (this.item.indexOf(tag) < 0)
            return;
        this.item.splice(this.item.indexOf(tag), 1);
        this.itemChange.emit(this.item);
    }
}
TagsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-tags',
                template: "<mat-form-field class=\"w-100\">\n\t<mat-chip-list #chipList>\n\t\t<mat-chip *ngFor=\"let chip of item\" [selectable]=\"false\" [removable]=\"true\" (removed)=\"removeTag(chip)\" [disabled]=\"!editing\">\n\t\t\t{{chip}}\n\t\t\t<mat-icon matChipRemove>cancel</mat-icon>\n\t\t</mat-chip>\n\t\t<input #inputfield [disabled]=\"!editing\" [(ngModel)]=\"search\" [placeholder]=\"label\" [matAutocomplete]=\"auto\" [matChipInputFor]=\"chipList\" (matChipInputTokenEnd)=\"add($event.value)\">\n\t</mat-chip-list>\n\t<mat-autocomplete #auto=\"matAutocomplete\" (optionSelected)=\"addTag($event.option.viewValue)\">\n\t\t<mat-option *ngFor=\"let tag of tags\" [value]=\"search\">\n\t\t\t{{tag}}\n\t\t</mat-option>\n\t</mat-autocomplete>\n</mat-form-field>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
TagsComponent.ctorParameters = () => [];
TagsComponent.propDecorators = {
    item: [{ type: Input }],
    label: [{ type: Input }],
    rawTags: [{ type: Input, args: ['tags',] }],
    editing: [{ type: Input }],
    itemChange: [{ type: Output }],
    enter: [{ type: Output }],
    inputfield: [{ type: ViewChild, args: ['inputfield',] }],
    matAutocomplete: [{ type: ViewChild, args: ['auto',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoadingComponent {
    constructor() {
        this.loading = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
LoadingComponent.decorators = [
    { type: Component, args: [{
                selector: 'ieeesb-loading',
                template: "<div class=\"loader\" *ngIf=\"loading\">\n\t<mat-progress-bar mode=\"indeterminate\"></mat-progress-bar>\n</div>\n",
                styles: [".loader{position:fixed;width:100%;height:100%;z-index:9999;background-color:rgba(221,221,221,.4)}"]
            }] }
];
/** @nocollapse */
LoadingComponent.ctorParameters = () => [];
LoadingComponent.propDecorators = {
    loading: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularIEEEsbLibModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AngularIEEEsbLibModule,
            providers: [UtilsService, LoadingService, WindowRef]
        };
    }
}
AngularIEEEsbLibModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SelectComponent,
                    ButtonComponent,
                    PaginationComponent,
                    SearchComponent,
                    ListComponent,
                    PropertyPipe,
                    MenuComponent,
                    SectionComponent,
                    FilterPipe,
                    TitleComponent,
                    TagsComponent,
                    LoadingComponent,
                ],
                imports: [
                    FormsModule,
                    ReactiveFormsModule,
                    CommonModule,
                    RouterModule,
                    HttpClientModule,
                    MatInputModule,
                    MatAutocompleteModule,
                    MatChipsModule,
                    MatIconModule,
                    MatSelectModule,
                    MatProgressBarModule,
                ],
                providers: [
                    UtilsService,
                    LoadingService,
                    WindowRef,
                ],
                exports: [
                    SelectComponent,
                    ButtonComponent,
                    PaginationComponent,
                    SearchComponent,
                    ListComponent,
                    MenuComponent,
                    SectionComponent,
                    FilterPipe,
                    TitleComponent,
                    TagsComponent,
                    LoadingComponent,
                    MatInputModule,
                    MatSlideToggleModule,
                    MatChipsModule,
                    MatButtonModule,
                    MatTabsModule,
                    BrowserAnimationsModule,
                    MatRippleModule,
                    MatIconModule,
                    MatCardModule,
                    MatToolbarModule,
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DriveService {
    /**
     * @param {?} winRef
     * @param {?} loadingService
     */
    constructor(winRef, loadingService) {
        this.winRef = winRef;
        this.loadingService = loadingService;
        this.host = '';
    }
    /**
     * @param {?} host
     * @return {?}
     */
    setHost(host) {
        this.host = host;
    }
    /**
     * @param {?=} type
     * @return {?}
     */
    getFile(type) {
        this.loadingService.setLoading();
        /** @type {?} */
        const responseSubject = new Subject();
        /** @type {?} */
        const query = `?type=${type ? type : 'all'}`;
        window.addEventListener("message", (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!event.data.file)
                return;
            console.log(event.data);
            responseSubject.next({
                file: event.data.file,
                url: event.data.url
            });
        }), false);
        /** @type {?} */
        const options = `width=${window.screen.availWidth},height=${window.screen.availHeight},toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no`;
        this.child = window.open(`${this.host}/#/browser${query}`, 'Browser', options);
        this.checkChild();
        return responseSubject.asObservable();
    }
    /**
     * @return {?}
     */
    checkChild() {
        if (this.child && this.child.closed) {
            return this.loadingService.unsetLoading();
        }
        setTimeout(this.checkChild.bind(this), 100);
    }
    /**
     * @return {?}
     */
    getImageFile() {
        return this.getFile('image');
    }
}
DriveService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
DriveService.ctorParameters = () => [
    { type: WindowRef },
    { type: LoadingService }
];
/** @nocollapse */ DriveService.ngInjectableDef = defineInjectable({ factory: function DriveService_Factory() { return new DriveService(inject(WindowRef), inject(LoadingService)); }, token: DriveService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AngularIEEEsbLibModule, ButtonComponent, SelectComponent, UtilsService, LoadingService, DriveService, WindowRef, FilterPipe as ɵg, ListComponent as ɵc, LoadingComponent as ɵj, MenuComponent as ɵe, PaginationComponent as ɵa, PropertyPipe as ɵd, SearchComponent as ɵb, SectionComponent as ɵf, TagsComponent as ɵi, TitleComponent as ɵh };

//# sourceMappingURL=angular-ieeesb-lib.js.map